Learn R Programming

gaussquad (version 1.0-1)

ghermite.h.quadrature.rules: Create list of generalized Hermite quadrature rules

Description

This function returns $a$ list with n elements containing the order $k$ quadrature rule data frame for the generalized Hermite polynomial for orders $k = 1,\;2,\; \ldots ,\;n$.

Usage

ghermite.h.quadrature.rules(n, mu)

Arguments

n
integer value for the highest integer order
mu
numeric value for the parameter of the generalized Hermite polynomial

Value

  • A list with $n$ elements each of which is a data frame
  • 1Quadrature rule data frame for the order 1 generalized Hermite polynomial
  • 2Quadrature rule data frame for the order 2 generalized Hermite polynomial
  • ...
  • nQuadrature rule data frame for the order $n$ generalized Hermite polynomial

Details

An order $k$ quadrature data frame is a named data frame that contains the roots and abscissa values of the corresponding order $k$ orthogonal polynomial. The column with name x contains the roots or zeros and the column with name w contains the weights.

References

Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York. Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992. Numerical Recipes in C, Cambridge University Press, Cambridge, U.K. Stroud, A. H., and D. Secrest, 1966. Gaussian Quadrature Formulas, Prentice-Hall, Englewood Cliffs, NJ.

See Also

quadrature.rules, schebyshev.t.quadrature

Examples

Run this code
###
### generate a list of quadrature rule data frames for
### the generalized Hermite polynomial
### of orders 1 to 5
###
rules <- ghermite.h.quadrature.rules( 5, 1 )
print( 5 )

Run the code above in your browser using DataLab