Learn R Programming

gaussquad (version 1.0-1)

glaguerre.quadrature.rules: Create list of generalized Laguerre quadrature rules

Description

This function returns a list with $n$ elements containing the order $k$ quadrature rule data frame for the generalized Laguerre polynomials for orders $k = 1,\;2,\; \ldots ,\;n$.

Usage

glaguerre.quadrature.rules(n,alpha)

Arguments

n
integer value for the highest order
alpha
numeric value for the polynomial parameter

Value

  • A list with $n$ elements each of which is a quadrature rule data frame
  • 1Quadrature rule for the order 1 generalized Laguerre polynomial
  • 2Quadrature rule for the order 2 generalized Laguerre polynomial
  • ...
  • nQuadrature rule for the order $n$ generalized Laguerre polynomial

Details

An order $k$ quadrature data frame is a named data frame that contains the roots and abscissa values of the corresponding order $k$ orthogonal polynomial. The column with name x contains the roots or zeros and the column with name w contains the weights.

References

Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York. Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992. Numerical Recipes in C, Cambridge University Press, Cambridge, U.K. Stroud, A. H., and D. Secrest, 1966. Gaussian Quadrature Formulas, Prentice-Hall, Englewood Cliffs, NJ.

See Also

quadrature.rules, glaguerre.quadrature

Examples

Run this code
###
### generate a list of quadrature rule data frames for
### the generalized Laguerre polynomials
### of orders 1 to 5
### polynomial parameter is 1.0
###
rules <- glaguerre.quadrature.rules( 5, 1 )
print( rules )

Run the code above in your browser using DataLab