jacobi.p.quadrature.rules: Create list of Jacobi quadrature rules
Description
This function returns a list with n elements containing
the order $k$ quadrature rule data frame for
the Jacobi P polynomial
for orders $k = 1,\;2,\; \ldots ,\;n$.
Usage
jacobi.p.quadrature.rules(n,a,b)
Arguments
n
integer value for the highest order
a
numeric value for the first polynomial parameter
b
numeric value for the second polynomial parameter
Value
A list with $n$ elements each of which is a quadrature rule data frame
1Quadrature rule for the order 1 Jacobi polynomial
2Quadrature rule for the order 2 Jacobi polynomial
...
nQuadrature rule for the order $n$ Jacobi polynomial
Details
An order $k$ quadrature data frame is a named data frame that contains
the roots and abscissa values of the corresponding order $k$ orthogonal polynomial.
The column with name x contains the roots or zeros and
the column with name w contains the weights.
References
Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with
Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York.
Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992.
Numerical Recipes in C, Cambridge University Press, Cambridge, U.K.
Stroud, A. H., and D. Secrest, 1966. Gaussian Quadrature Formulas,
Prentice-Hall, Englewood Cliffs, NJ.