Learn R Programming

gaussquad (version 1.0-1)

quadrature.rules: Create a list of quadrature rule data frames

Description

This function returns a list with $n$ elements containing the order $k$ quadrature rule data frames for orders $k = 1,\;2,\; \ldots ,\;n$.

Usage

quadrature.rules(recurrences, inner.products)

Arguments

recurrences
a data frame with the recurrence parameters of a particular orthogonal polynomial
inner.products
a numeric vector of normed squared values of the orthogonal polynomials

Value

  • A list with $n$ elements each of which is a quadrature rule data frame
  • 1Quadrature rule for the order 1 orthogonal polynomial
  • 2Quadrature rule for the order 2 orthogonal polynomial
  • ...
  • nQuadrature rule for the order $n$ orthogonal polynomial

Details

An order $k$ quadrature data frame is a named data frame that contains the roots and abscissa values for the quadrature rule based on an order $k$ orthgonal polynomial.

References

Abramwitz and Stegun (1968)

Examples

Run this code
###
### get recurrences the Chebyshev T orthgonal polynomials
### of orders 0 to 6\5
###
recurrences <- chebyshev.t.recurrences( 5 )
###
### get the inner products of these polynomials
###
inner.products <- chebyshev.t.inner.products( 5 )
###
### get the quadrature rules
###
rules <- quadrature.rules( recurrences, inner.products )
print( rules )

Run the code above in your browser using DataLab