schebyshev.u.quadrature.rules: Create list of shifted Chebyshev quadrature rules
Description
This function returns a list with $n$ elements containing
the order $k$ quadrature rule data frame for
the shifted Chebyshev U polynomial of the first kind
for orders $k = 1,\;2,\; \ldots ,\;n$.
Usage
schebyshev.u.quadrature.rules(n)
Arguments
n
integer value for the highest order
Value
A list with $n$ elements each of which is a data frame
1Quadrature rule data frame for the order 1 shifted Chebyshev polynomial
2Quadrature rule data frame for the order 2 shifted Chebyshev polynomial
...
nQuadrature rule data frame for the order $n$ shifted Chebyshev polynomial
Details
An order $k$ quadrature data frame is a named data frame that contains
the roots and abscissa values of the corresponding order $k$ orthogonal polynomial.
The column with name x contains the roots or zeros and
the column with name w contains the weights.
References
Abramowitz, M. and I. A. Stegun, 1968. Handbook of Mathematical Functions with
Formulas, Graphs, and Mathematical Tables, Dover Publications, Inc., New York.
Press, W. H., S. A. Teukolsky, W. T. Vetterling, and B. P. Flannery, 1992.
Numerical Recipes in C, Cambridge University Press, Cambridge, U.K.
Stroud, A. H., and D. Secrest, 1966. Gaussian Quadrature Formulas,
Prentice-Hall, Englewood Cliffs, NJ.
###### generate the quadrature rules for### the shifted Chebyshev U polynomials### of orders 1 to 5###rules <- schebyshev.u.quadrature.rules( 5 )
print( 5 )