legendre.quadrature.rules: Create list of Legendre quadrature rules
Description
This function returns a list with $n$ elements containing
the order $k$ quadrature rule data frame for
the Legendre polynomial
for orders $k = 1,\;2,\; \ldots ,\;n$.
Usage
legendre.quadrature.rules(n)
Arguments
n
integer value for the highest order
Value
A list with $n$ elements each of which is a data frame
1Quadrature rule data frame for the order 1 Legendre polynomial
2Quadrature rule data frame for the order 2 Legendre polynomial
...
nQuadrature rule data frame for the order $n$ Legendre polynomial
Details
An order $k$ quadrature data frame is a named data frame that contains
the roots and abscissa values of the corresponding order $k$ orthogonal polynomial.
The column with name x contains the roots or zeros and
the column with name w contains the weights.
References
Abramowitz and Stegun (1968), Press et. al. (1992)
###### generate a list of quadrature rule frames for### the Legendre polynomials### of orders 1 to 5###rules <- legendre.quadrature.rules( 5 )
print( rules )